==========
Pick n Mix
==========


.. image:: https://img.shields.io/pypi/v/picknmix.svg
        :target: https://pypi.python.org/pypi/picknmix

.. image:: https://img.shields.io/travis/Cheukting/picknmix.svg
        :target: https://travis-ci.org/Cheukting/picknmix

.. image:: https://readthedocs.org/projects/picknmix/badge/?version=latest
        :target: https://picknmix.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A simple tool to help building stacking models.


* Free software: MIT license
* Documentation: https://picknmix.readthedocs.io.


Features
--------

Pick N Mix is a simple stacking tool for stacking Sci-Kit learn models of your picks.
It provided 2 classes: Layer and Stack. Layer is a parallel combination of models,
while Stack combine Layers to create a stacking model.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
